@@ -1,7 +1,6 @@
 
 /*
-  $Id: frencode.h,v 1.4 2005/12/02 14:21:30 ldv Exp $
-  Copyright (C) 2002, 2005  Dmitry V. Levin <ldv@altlinux.org>
+  Copyright (C) 2002, 2005, 2006  Dmitry V. Levin <ldv@altlinux.org>
 
   The frencode declaration.
 
@@ -20,9 +19,9 @@
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */
 
-#ifndef __FRENCODE_H__
-#define __FRENCODE_H__
+#ifndef FRENCODE_H__
+#define FRENCODE_H__
 
 extern void frencode(int fd, const char *path);
 
-#endif /* __FRENCODE_H__ */
+#endif /* FRENCODE_H__ */
