@@ -1,7 +1,6 @@
 
 /*
-  $Id: glob.c,v 1.5 2005/12/02 14:21:30 ldv Exp $
-  Copyright (C) 2002, 2004, 2005  Dmitry V. Levin <ldv@altlinux.org>
+  Copyright (C) 2002-2006  Dmitry V. Levin <ldv@altlinux.org>
 
   The glob method for locate.
 
@@ -26,24 +25,27 @@
 #include <stdlib.h>
 #include <fnmatch.h>
 
-#include "methods.h"
+#include "match.h"
 
-void   *
-glob_open(const char *pattern, __attribute__ ((unused))
-	  int icase)
+static bool
+glob_match(const char *sample, match_context *context)
 {
-	return (void *) pattern;
-}
-
-int
-glob_match(void *handle, const char *sample, int icase)
-{
-	const char *pattern = (const char *) handle;
-	int     rc = fnmatch(pattern, sample, icase ? FNM_CASEFOLD : 0);
+	const char *pattern = context->data;
+	int     rc = fnmatch(pattern, sample,
+			     context->ignore_case ? FNM_CASEFOLD : 0);
 
 	if (!rc)
-		return 1;
+		return true;
 	else if (FNM_NOMATCH != rc)
 		error(EXIT_FAILURE, errno, "fnmatch");
-	return 0;
+	return false;
+}
+
+void
+glob_match_init(const char *pattern, match_context *context,
+		locate_settings *settings)
+{
+	context->matcher = glob_match;
+	context->data = (void *) pattern;
+	context->ignore_case = settings->ignore_case;
 }
