@@ -1,7 +1,6 @@
 
 /*
-  $Id: lists.h,v 1.7 2005/12/02 14:33:47 ldv Exp $
-  Copyright (C) 2002, 2003, 2005  Dmitry V. Levin <ldv@altlinux.org>
+  Copyright (C) 2002-2006  Dmitry V. Levin <ldv@altlinux.org>
 
   The list manipulations.
 
@@ -20,8 +19,8 @@
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */
 
-#ifndef __LISTS_H__
-#define __LISTS_H__
+#ifndef LISTS_H__
+#define LISTS_H__
 
 #include <sys/types.h>
 
@@ -39,4 +38,4 @@ extern size_t fstype_list_size;
 
 extern void convert_fs_paths(void);
 
-#endif /* __LISTS_H__ */
+#endif /* LISTS_H__ */
