@@ -1,7 +1,6 @@
 
 /*
-  $Id: nextelem.h,v 1.4 2005/12/02 14:21:30 ldv Exp $
-  Copyright (C) 2002, 2005  Dmitry V. Levin <ldv@altlinux.org>
+  Copyright (C) 2002, 2005, 2006  Dmitry V. Levin <ldv@altlinux.org>
 
   The next_element declaration.
 
@@ -20,9 +19,9 @@
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */
 
-#ifndef __NEXTELEM_H__
-#define __NEXTELEM_H__
+#ifndef NEXTELEM_H__
+#define NEXTELEM_H__
 
 extern const char *next_element(const char *new_path);
 
-#endif /* __NEXTELEM_H__ */
+#endif /* NEXTELEM_H__ */
