@@ -1,7 +1,6 @@
 
 /*
-  $Id: scantree.h,v 1.4 2005/12/02 14:21:30 ldv Exp $
-  Copyright (C) 2002, 2005  Dmitry V. Levin <ldv@altlinux.org>
+  Copyright (C) 2002, 2005, 2006  Dmitry V. Levin <ldv@altlinux.org>
 
   The scantree declaration.
 
@@ -20,9 +19,9 @@
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */
 
-#ifndef __SCANTREE_H__
-#define __SCANTREE_H__
+#ifndef SCANTREE_H__
+#define SCANTREE_H__
 
 extern void scantree(int fd);
 
-#endif /* __SCANTREE_H__ */
+#endif /* SCANTREE_H__ */
