@@ -1,7 +1,6 @@
 
 /*
-  $Id: substr.c,v 1.6 2005/12/02 14:21:30 ldv Exp $
-  Copyright (C) 2002, 2004, 2005  Dmitry V. Levin <ldv@altlinux.org>
+  Copyright (C) 2002-2006  Dmitry V. Levin <ldv@altlinux.org>
 
   The substr method for locate.
 
@@ -21,19 +20,24 @@
 */
 
 #include <string.h>
-#include "methods.h"
 
-void   *
-substr_open(const char *pattern, __attribute__ ((unused))
-	    int icase)
+#include "match.h"
+
+static bool
+substr_match(const char *sample, match_context *context)
 {
-	return (void *) pattern;
+	const char *pattern = context->data;
+
+	return (context->ignore_case ? strcasestr : strstr) (sample,
+							     pattern) ? true
+		: false;
 }
 
-int
-substr_match(void *handle, const char *sample, int icase)
+void
+substr_match_init(const char *pattern, match_context *context,
+		  locate_settings *settings)
 {
-	const char *pattern = (const char *) handle;
-
-	return (icase ? strcasestr : strstr) (sample, pattern) ? 1 : 0;
+	context->matcher = substr_match;
+	context->data = (void *) pattern;
+	context->ignore_case = settings->ignore_case;
 }
