@@ -1,7 +1,6 @@
 
 /*
-  $Id: updatedb.h,v 1.4 2005/12/02 14:21:30 ldv Exp $
-  Copyright (C) 2002, 2005  Dmitry V. Levin <ldv@altlinux.org>
+  Copyright (C) 2002, 2005, 2006  Dmitry V. Levin <ldv@altlinux.org>
 
   The updatedb declaration.
 
@@ -20,11 +19,11 @@
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */
 
-#ifndef __UPDATEDB_H__
-#define __UPDATEDB_H__
+#ifndef UPDATEDB_H__
+#define UPDATEDB_H__
 
 #include <sys/types.h>
 
 extern void updatedb(int fd, const char *runas, int keep_cap);
 
-#endif /* __UPDATEDB_H__ */
+#endif /* UPDATEDB_H__ */
