@@ -1,7 +1,6 @@
 
 /*
-  $Id: xmalloc.h,v 1.5 2005/12/02 14:21:30 ldv Exp $
-  Copyright (C) 2002, 2003, 2005  Dmitry V. Levin <ldv@altlinux.org>
+  Copyright (C) 2002-2006  Dmitry V. Levin <ldv@altlinux.org>
 
   Dynamic memory allocation with error checking.
 
@@ -20,14 +19,14 @@
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */
 
-#ifndef __XMALLOC_H__
-#define __XMALLOC_H__
+#ifndef XMALLOC_H__
+#define XMALLOC_H__
 
 extern void *xmalloc(size_t size);
 extern void *xcalloc(size_t nmemb, size_t size);
 extern void *xrealloc(void *ptr, size_t size);
 extern char *xstrdup(const char *s);
 extern char *xasprintf(char **ptr, const char *fmt, ...)
-	__attribute__ ((__format__(__printf__, 2, 3)));
+	__attribute__((__format__(__printf__, 2, 3)));
 
-#endif /* __XMALLOC_H__ */
+#endif /* XMALLOC_H__ */
